<?php

namespace Litepie\News\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litepie\News\Models\News;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litepie\News\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/news/news/*')) {
            Route::bind('news', function ($news) {
                $newsrepo = $this->app->make('Litepie\News\Interfaces\NewsRepositoryInterface');
                return $newsrepo->findorNew($news);
            });
        }

        if (Request::is('*/news/news_category/*')) {
            Route::bind('news_category', function ($news_category) {
                $news_categoryrepo = $this->app->make('Litepie\News\Interfaces\NewsCategoryRepositoryInterface');
                return $news_categoryrepo->findorNew($news_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
